require "import"
import "android.widget.*"
import "android.content.*"
import "android.view.View"

-- Localized strings
local strings = {
  title = "Pencarian dan Penggantian Teks",
  createdBy = "Created by Zain Muhammad Haikal",
  inputLabel = "Masukkan teks Anda di sini:",
  searchLabel = "Cari:",
  replaceLabel = "Ganti dengan:",
  searchButton = "Cari dan Ganti",
  clearButton = "Bersihkan",
  closeButton = "Tutup",
  aboutButton = "Cara Penggunaan",
  resultLabel = "Hasil:",
  aboutTitle = "Cara Penggunaan",
  aboutContent = "1. Masukkan teks yang ingin Anda ubah.\n2. Masukkan kata yang ingin dicari.\n3. Masukkan kata pengganti.\n4. Tekan tombol 'Cari dan Ganti' untuk mengganti kata yang dicari dengan kata pengganti.\n5. Hasil perubahan akan ditampilkan di bawah.\n\nSalam dari Zain Muhammad Haikal. Indonesia tidak boleh pecah kongsi.",
}

-- Create UI elements
local inputLayout = {
  LinearLayout;
  orientation = "vertical",
  layout_width = "fill",
  {
    TextView;
    text = strings.createdBy,
    textSize = 16,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    TextView;
    text = strings.inputLabel,
    textSize = 18,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    EditText;
    id = "textInput",
    layout_width = "fill",
    layout_height = "150dp",
    gravity = "top",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    TextView;
    text = strings.searchLabel,
    textSize = 18,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    EditText;
    id = "searchInput",
    layout_width = "fill",
    layout_height = "wrap_content",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    TextView;
    text = strings.replaceLabel,
    textSize = 18,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    EditText;
    id = "replaceInput",
    layout_width = "fill",
    layout_height = "wrap_content",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    LinearLayout;
    orientation = "horizontal",
    layout_width = "fill",
    {
      Button;
      text = strings.searchButton,
      id = "searchButton",
      layout_weight = 1,
      layout_margin = "5dp"
    },
    {
      Button;
      text = strings.clearButton,
      id = "clearButton",
      layout_weight = 1,
      layout_margin = "5dp"
    }
  },
  {
    TextView;
    text = strings.resultLabel,
    textSize = 18,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  },
  {
    TextView;
    id = "resultView",
    textSize = 16,
    textColor = 0xff000000,
    layout_width = "wrap",
    layout_marginTop = "10dp",
    layout_marginLeft = "10dp",
    layout_marginRight = "10dp"
  }
}

-- Create dialog
local dlg = LuaDialog()
dlg.setTitle(strings.title)
dlg.setView(loadlayout(inputLayout))

-- Set up search and replace button functionality
searchButton.onClick = function()
  local text = textInput.text
  local search = searchInput.text
  local replace = replaceInput.text

  if search ~= "" then
    local replacedText = text:gsub(search, replace)
    resultView.setText(replacedText)
  else
    Toast.makeText(this, "Kata yang dicari tidak boleh kosong", Toast.LENGTH_SHORT).show()
  end
end

-- Set up clear button functionality
clearButton.onClick = function()
  textInput.setText("")
  searchInput.setText("")
  replaceInput.setText("")
  resultView.setText("")
end

-- Set up about button functionality
local function showAboutDialog()
  local aboutDialog = LuaDialog(this)
  aboutDialog.setTitle(strings.aboutTitle)
  aboutDialog.setMessage(strings.aboutContent)
  aboutDialog.setPositiveButton("OK", nil)
  aboutDialog.show()
end

-- Add about button to dialog
dlg.setButton2(strings.aboutButton, function()
  showAboutDialog()
end)

-- Set the close button
dlg.setButton3(strings.closeButton, function()
  dlg.dismiss()
end)

dlg.show()